summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/klistviewsearchline.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/klistviewsearchline.h')
-rw-r--r--kmymoney2/widgets/klistviewsearchline.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmymoney2/widgets/klistviewsearchline.h b/kmymoney2/widgets/klistviewsearchline.h
index b41d3ad..1ecb94b 100644
--- a/kmymoney2/widgets/klistviewsearchline.h
+++ b/kmymoney2/widgets/klistviewsearchline.h
@@ -52,13 +52,13 @@ public:
* If \a listView is null then the widget will be disabled until a listview
* is set with setListView().
*/
- KListViewSearchLine(TQWidget *tqparent = 0, KListView *listView = 0, const char *name = 0);
+ KListViewSearchLine(TQWidget *parent = 0, KListView *listView = 0, const char *name = 0);
/**
* Constructs a KListViewSearchLine without any KListView to filter. The
* KListView object has to be set later with setListView().
*/
- KListViewSearchLine(TQWidget *tqparent, const char *name);
+ KListViewSearchLine(TQWidget *parent, const char *name);
/**
* Destroys the KListViewSearchLine.
@@ -111,7 +111,7 @@ public slots:
/**
* When a search is active on a list that's organized into a tree view if
* a tqparent or ancesestor of an item is does not match the search then it
* will be hidden and as such so too will any tqchildren that match.
*
* If this is set to true (the default) then the parents of matching items
@@ -183,13 +183,13 @@ protected slots:
private:
/**
* This is used in case tqparent items of matching items shouldn't be
* visible. It hides all items that don't match the search string.
*/
void checkItemParentsNotVisible();
/**
* This is used in case tqparent items of matching items should be visible.
* It makes a recursive call to all tqchildren. It returns true if at least
* one item in the subtree with the given root item is visible.
*/
@@ -218,10 +218,10 @@ class KMYMONEY_EXPORT KListViewSearchLineWidget : public TQHBox
public:
/**
* Creates a KListViewSearchLineWidget for \a listView with \a tqparent as the
* tqparent with and \a name.
*/
- KListViewSearchLineWidget(KListView *listView = 0, TQWidget *tqparent = 0,
+ KListViewSearchLineWidget(KListView *listView = 0, TQWidget *parent = 0,
const char *name = 0);
/**
@@ -111,7 +111,7 @@ public slots:
/**
* When a search is active on a list that's organized into a tree view if
- * a tqparent or ancesestor of an item is does not match the search then it
+ * a parent or ancesestor of an item is does not match the search then it
* will be hidden and as such so too will any tqchildren that match.
*
@@ -183,13 +183,13 @@ protected slots:
private:
/**
- * This is used in case tqparent items of matching items shouldn't be
+ * This is used in case parent items of matching items shouldn't be
* visible. It hides all items that don't match the search string.
*/
@@ -183,13 +183,13 @@ protected slots:
void checkItemParentsNotVisible();
/**
- * This is used in case tqparent items of matching items should be visible.
+ * This is used in case parent items of matching items should be visible.
* It makes a recursive call to all tqchildren. It returns true if at least
* one item in the subtree with the given root item is visible.
@@ -218,10 +218,10 @@ class KMYMONEY_EXPORT KListViewSearchLineWidget : public TQHBox
public:
/**
- * Creates a KListViewSearchLineWidget for \a listView with \a tqparent as the
- * tqparent with and \a name.
+ * Creates a KListViewSearchLineWidget for \a listView with \a parent as the
+ * parent with and \a name.
*/